HASS Configurator

- git init
- git commit
- git push
- git stash

- git init
- git commit
- git push
- git stash

#### Savesave

Do you really want to save?

#### Upload Filefile_upload

Please choose a file to upload

File

#### git init

Are you sure you want to initialize a repository at the current path?

#### git commit

Commit message

#### git push

Are you sure you want to push your commited changes to the configured remote / origin?

#### git stash

Are you sure you want to stash your changes?

#### Close Fileclose

Are you sure you want to close the current file? Unsaved changes will be lost.

#### Rename

Please enter a new name for .

#### Delete

Are you sure you want to delete ?

#### git add

Are you sure you want to add to the index?

#### Check configuration

Do you want to check the configuration?

#### Reload automations

Do you want to reload the automations?

#### Reload scripts

Do you want to reload the scripts?

#### Reload groups

Do you want to reload the groups?

#### Reload core

Do you want to reload the core?

#### Restart

Do you really want to restart Home Assistant?

#### Remove allowed network / IP

Do you really want to remove the network / IP from the list of allowed networks?

#### Add allowed network / IP

Do you really want to Add the network / IP to the list of allowed networks?

#### Unban IP

Do you really want to unban the IP ?

#### Ban IP

Do you really want to ban the IP ?

#### Execute shell command

Command

#### Unsaved Changessave

You have unsaved changes in the current file. Please save the changes or close the file before opening a new one.

#### New Foldercreate_new_folder

New Folder Name

#### New Filenote_add

New File Name

#### New Branch

New Branch Name

#### Network status

Your address: $your_address

Listening address: $listening_address

HASS API address: $hass_api_address

Modifying the following lists is not persistent. To statically control access please use the configuration file.

Add network / IP

Ban IP
edit

- undo
- redo
- format_indent_increase
- format_indent_decrease
- all_out
- #